@@ -81,6 +81,7 @@ typedef enum {
  * @FLATPAK_STORAGE_TYPE_HARD_DISK: installation is on a hard disk
  * @FLATPAK_STORAGE_TYPE_SDCARD: installation is on a SD card
  * @FLATPAK_STORAGE_TYPE_MMC: installation is on an MMC
+ * @FLATPAK_STORAGE_TYPE_NETWORK: installation is on the network
  *
  * Flags to alter the behavior of flatpak_installation_install_full().
  *
@@ -91,6 +92,7 @@ typedef enum {
   FLATPAK_STORAGE_TYPE_HARD_DISK,
   FLATPAK_STORAGE_TYPE_SDCARD,
   FLATPAK_STORAGE_TYPE_MMC,
+  FLATPAK_STORAGE_TYPE_NETWORK,
 } FlatpakStorageType;
 
 
@@ -174,9 +176,15 @@ FLATPAK_EXTERN FlatpakInstalledRef * flatpak_installation_get_current_installed_
                                                                                      const char          *name,
                                                                                      GCancellable        *cancellable,
                                                                                      GError             **error);
+
 FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_remotes (FlatpakInstallation *self,
                                                                        GCancellable        *cancellable,
                                                                        GError             **error);
+FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_remotes_by_type (FlatpakInstallation     *self,
+                                                                               const FlatpakRemoteType  types[],
+                                                                               gsize                    num_types,
+                                                                               GCancellable            *cancellable,
+                                                                               GError                 **error);
 FLATPAK_EXTERN FlatpakRemote        *flatpak_installation_get_remote_by_name (FlatpakInstallation *self,
                                                                               const gchar         *name,
                                                                               GCancellable        *cancellable,
@@ -193,6 +201,15 @@ FLATPAK_EXTERN gboolean              flatpak_installation_update_remote_sync (Fl
                                                                               const char          *name,
                                                                               GCancellable        *cancellable,
                                                                               GError             **error);
+FLATPAK_EXTERN gboolean              flatpak_installation_set_config_sync (FlatpakInstallation *self,
+									   const char          *key,
+									   const char          *value,
+									   GCancellable        *cancellable,
+									   GError             **error);
+FLATPAK_EXTERN char *                flatpak_installation_get_config      (FlatpakInstallation *self,
+									   const char          *key,
+									   GCancellable        *cancellable,
+									   GError             **error);
 FLATPAK_EXTERN char *              flatpak_installation_load_app_overrides (FlatpakInstallation *self,
                                                                             const char          *app_id,
                                                                             GCancellable        *cancellable,
@@ -273,7 +290,7 @@ FLATPAK_EXTERN GBytes        *   flatpak_installation_fetch_remote_metadata_sync
                                                                                   GCancellable        *cancellable,
                                                                                   GError             **error);
 FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_refs_sync (FlatpakInstallation *self,
-                                                                             const char          *remote_name,
+                                                                             const char          *remote_or_uri,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
 FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync (FlatpakInstallation *self,
